/*
 * Copyright (c) 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template.servlet;

import fi.iki.hsivonen.template.DataSource;
import fi.iki.hsivonen.template.DataSourceException;

/**
 * This interface makes it possible to provide singleton access or factory 
 * access to <code>DataSource</code> instances. If the <code>DataSource</code> 
 * implementation is a singleton, the <code>dataSource()</code> should 
 * return the singleton instance. If the <code>DataSource</code> implementation 
 * requires each thread/request to have its own instance of the 
 * <code>DataSource</code> the <code>dataSource()</code> can act as a factory 
 * and merely call the constructor of the <code>dataSource()</code> 
 * implementation.
 * 
 * <p>
 * The implementation of this interface is required to have a constructor 
 * that takes no arguments. The implementation is registered by storing the 
 * FQN of the implementation in the 
 * <code>fi.iki.hsivonen.template.servlet.datasourcesource</code> system 
 * property.
 * 
 * @version $Id: DataSourceSource.java,v 1.2 2004/08/30 17:12:28 hsivonen Exp $
 * @author hsivonen
 */
public interface DataSourceSource {
    
    /**
     * Returns an instance of <code>DataSource</code> (either a new one or a 
     * thread-safe singleton). The implementation of this method itself must 
     * be thread-safe.
     * 
     * @return an instance of <code>DataSource</code>
     * @throws DataSourceException if anything goes wrong
     */
    public DataSource dataSource() throws DataSourceException;
}
