/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.front;

import java.util.LinkedHashMap;
import java.util.Map;

public class LRUFileMap extends LinkedHashMap {

    /** Maximum number of stored files */
    private int maxFiles;

    /** Load factor for the map */
    private static final float loadFactor = 0.75f;

    /**
     * Class constructor
     * @param mf maximum number of stored files
     */
    public LRUFileMap(int mf) {
        super((int)((mf + 1) / loadFactor), loadFactor, true);
        maxFiles = mf;
    }

    /**
     * Returns true if the number of stored files exceed the maximum number 
     * of files. Invalidates the eldest file as a side effect.
     * @return true if the eldest entry should be removed
     */
    protected boolean removeEldestEntry(Map.Entry eldest) {
        if (size() > maxFiles) {
            CachedFile cf = (CachedFile)eldest.getValue();
            cf.invalidate();
            return true;
        } else {
            return false;
        }
    }
}
